@@ -18,7 +18,7 @@ __author__ = "uak"
 __copyright__ = "Copyright 2022"
 __credits__ = ["uak"]
 __license__ = "LGPL"
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 
 class EcSLP:
@@ -77,13 +77,29 @@ class EcSLP:
         # ~ return set_ids
     
     
-    def get_rpc_user_data(self):
+    def get_config_data(self, params, config_option):
         """
-        Assign authantication data based on EC configuration.
+        Get config data from Electron Cash wallet configuration file.
         """
-        config_dict["rpc_user"] = self.subprocessing(("getconfig","rpcuser")).rstrip()
-        config_dict["rpc_password"] = self.subprocessing(("getconfig","rpcpassword")).rstrip()
+        cmd = ("getconfig", config_option)
+
+        try:
+            return self.subprocessing(cmd, params).rstrip()
+        except Exception as err:
+            raise
+
+
+    def set_config_data(self, params, config_option, value):
+        """
+        Set config data to Electron Cash wallet configuration file.
+        """
+        cmd = ("setconfig", config_option, value)
         
+        try:
+            return self.subprocessing(cmd, params).rstrip()
+        except Exception as err:
+            raise
+
     
     def ec_rpc(
                 self,
